@@ -3,7 +3,7 @@
 //
 //  This file is part of Linterna Mágica
 //
-//  Copyright (C) 2010, 2011  Ivaylo Valkov <ivaylo@e-valkov.org>
+//  Copyright (C) 2010, 2011, 2012  Ivaylo Valkov <ivaylo@e-valkov.org>
 //  Copyright (C) 2010  Anton Katsarov <anton@katsarov.org>
 //
 //  The JavaScript code in this page (or file) is free software: you
@@ -77,7 +77,14 @@ LinternaMagica.prototype.switch_to_hd_link = function(event, element)
 
 	// The ticker function stops and deletes the previous
 	// timer/interval when there is no acces to the object.
-	this.player.init.apply(this,[id]);
+	if (this.controls)
+	{
+	    this.player.init.apply(this,[id]);
+	}
+	else if(!this.controls && !this.get_player_name(id))
+	{
+	    this.player.set_player_name.apply(this,[id]);
+	}
 
 	var control_id = "linterna-magica-controls-button-play-"+id;
 	var play = document.getElementById(control_id);
@@ -105,6 +112,7 @@ LinternaMagica.prototype.switch_to_hd_link = function(event, element)
 
 	// hide the list
 	div.style.setProperty("display", "none", "important");
+	this.set_video_object_width_on_hd_list_display_change(id);
     }
 }
 
@@ -118,13 +126,16 @@ LinternaMagica.prototype.show_or_hide_hd_links = function(event, element)
     id = id[id.length-1];
 
     var hd_list = element.nextSibling;
+   
     if (hd_list)
     {
 	var display = hd_list.style.getPropertyValue("display");
 	if (display)
 	{
 	    hd_list.style.removeProperty("display");
+	    this.set_video_object_width_on_hd_list_display_change(id);
 
+	    var self = this;
 	    var hd_list_blur_function = function(ev)
 	    {
 		var timeout_function = function()
@@ -137,6 +148,9 @@ LinternaMagica.prototype.show_or_hide_hd_links = function(event, element)
 		    {
 			hd_list.style.setProperty("display", 
 						  "none", "important");
+			self.
+			    set_video_object_width_on_hd_list_display_change.
+			    apply(self, [id]);
 		    }
 		    element.removeEventListener("blur",
 						hd_list_blur_function,
@@ -153,11 +167,52 @@ LinternaMagica.prototype.show_or_hide_hd_links = function(event, element)
 	else
 	{
 	    hd_list.style.setProperty("display", "none", "important");
-	}
+	    this.set_video_object_width_on_hd_list_display_change(id);
+ 	}
     }
     return true;
 }
 
+LinternaMagica.prototype.set_video_object_width_on_hd_list_display_change =
+function(linterna_magica_id)
+{
+    var hd_list = document.getElementById("linterna-magica-hd-links-list-"+
+					 linterna_magica_id);
+
+    var lm_video = this.get_video_object(linterna_magica_id);
+
+    if (!hd_list || !lm_video)
+    {
+	return;
+    }
+
+    if (hd_list.video_normal_width == undefined)
+    {
+	var hd_list_width = hd_list.clientWidth ? 
+	    hd_list.clientWidth : hd_list.offsetWidth ? 
+	    hd_list.offsetWidth : 120;
+
+	hd_list.video_normal_width = 
+	    parseInt(lm_video.style.getPropertyValue("width"));
+
+	// 20 = offset from the right to the middle
+	hd_list.video_reduced_width = 
+	    hd_list.video_normal_width - hd_list_width - 20;
+    }
+
+    if (hd_list.style.getPropertyValue('display'))
+    {
+
+	lm_video.style.setProperty("width", hd_list.video_normal_width+"px",
+				   "important");
+    }
+    else
+    {
+	lm_video.style.setProperty("width", hd_list.video_reduced_width+"px",
+			       "important");
+    }
+}
+
 // Set style and id of the selected link in the HD list. This way it
 // is distinguished.
 LinternaMagica.prototype.select_hd_link_in_list = function(element,id)
@@ -216,6 +271,7 @@ LinternaMagica.prototype.create_hd_links_button = function(object_data)
 
     var hd_wrapper = document.createElement("div");
     hd_wrapper.setAttribute("id", "linterna-magica-hd-wrapper-"+id);
+    hd_wrapper.setAttribute("class", "linterna-magica-hd-wrapper");
 
     var hd_button = document.createElement("a");
 
@@ -297,3 +353,4 @@ LinternaMagica.prototype.create_hd_links_list = function(object_data)
 
     return hd_links;
 }
+
